katsdpsigproc.rfi.test package
==============================

Submodules
----------

katsdpsigproc.rfi.test.test\_background module
----------------------------------------------

.. automodule:: katsdpsigproc.rfi.test.test_background
   :members:
   :undoc-members:
   :show-inheritance:

katsdpsigproc.rfi.test.test\_flagger module
-------------------------------------------

.. automodule:: katsdpsigproc.rfi.test.test_flagger
   :members:
   :undoc-members:
   :show-inheritance:

katsdpsigproc.rfi.test.test\_noise\_est module
----------------------------------------------

.. automodule:: katsdpsigproc.rfi.test.test_noise_est
   :members:
   :undoc-members:
   :show-inheritance:

katsdpsigproc.rfi.test.test\_threshold module
---------------------------------------------

.. automodule:: katsdpsigproc.rfi.test.test_threshold
   :members:
   :undoc-members:
   :show-inheritance:

katsdpsigproc.rfi.test.test\_twodflag module
--------------------------------------------

.. automodule:: katsdpsigproc.rfi.test.test_twodflag
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: katsdpsigproc.rfi.test
   :members:
   :undoc-members:
   :show-inheritance:
